import Vue from "vue";
import VueRouter, { Route, RouteConfig } from "vue-router";
import layout from "../views/layout/index.vue";
import { getTitle } from "@/utils";
import user from "@/store/modules/user";
import { Loading } from "element-ui";
import { Message } from "@/utils/message";
import { login } from "@/utils/cookies";
Vue.use(VueRouter);
const router = new VueRouter({
  mode: "history",
  base: process.env.BASE_URL,
  scrollBehavior(to, from, savedPosition) {
    if (savedPosition) {
      return savedPosition;
    } else {
      return { x: 0, y: 0 };
    }
  },
  routes: [
    {
      path: "/",
      component: layout,
      redirect: "/home",
      children: [
        {
          path: "/home",
          component: () => import("../views/home/index.vue"),
          meta: { title: "首页", nav: true }
        }
      ]
    },
    {
      path: "/error/:code",
      component: () => import("../views/error.vue")
    }
  ]
});

let loading: any;
router.beforeEach(async (to, from, next) => {
  const { token } = to.query;
  if (typeof token === "string") {
    await user.setToken(token);
    return next(login.get());
  }
  if (user.Token && !user.UserInfo) {
    await user.getUserInfo();
  }
  let errCode = 0;
  if (!to.matched.length) errCode = 404;
  if (to.path.startsWith("/user") && !user.UserInfo) errCode = 401;
  if (user.UserInfo === null && to.matched.some(({ meta: { auth } }) => auth)) {
    Message.warning("请先登录！");
    return next(false);
  }
  loading = Loading.service({
    fullscreen: true,
    text: "跳转中..."
  });
  if (errCode)
    return next({
      path: `/error/${errCode}`,
      replace: true
    });
  const title = getTitle(to);
  if (title) document.title = `${title} - ${process.env.VUE_APP_publicName}`;
  next();
});
router.afterEach((to, from) =>
  setTimeout(() => {
    loading.close();
  })
);
export default router;
