import {
  VuexModule,
  Module,
  getModule,
  Mutation,
  Action,
  MutationAction
} from "vuex-module-decorators";
import { auth } from "@/utils/cookies";
import { getUserInfo } from "@/api/user";
import store from "../index";

@Module({ dynamic: true, store, name: "user" })
class User extends VuexModule {
  public Token = auth.getToken() || "";
  public UserInfo: IUser | null = null;
  @Action({ commit: "setUserInfo" })
  public async getUserInfo() {
    if (!this.Token) return null;
    const userInfo = await getUserInfo(this.Token);
    if (userInfo === null) this.clear();
    return userInfo;
  }
  @Mutation
  private setUserInfo(userInfo: IUser | null) {
    this.UserInfo = userInfo;
  }
  @Mutation
  private set_token(token: string) {
    this.Token = token;
  }
  @Action({ commit: "set_token" })
  public setToken(token: string) {
    if (this.UserInfo) return this.Token;
    auth.setToken(token);
    return token;
  }
  @Mutation
  public clear() {
    this.Token = "";
    this.UserInfo = null;
    auth.removeToken();
  }
}
export default getModule(User);
