import { Route, RouteConfig } from "vue-router";

export const getLevel = (level: string) => {
  switch (level) {
    case "1":
      return 3;
    case "2":
      return 1;

    case "3":
      return 2;
  }
  return 0;
};

const titles: IBreadCrumbs[] = [];
export const setTitles = (router: any) =>
  titles.push(
    ...getChildren(router.options.routes[0].children as RouteConfig[])
  );
const getChildren = (route: RouteConfig[], parent = "") => {
  const t: IBreadCrumbs[] = [];

  route.forEach(({ path, children, meta: { title } = { title: "" } }) => {
    const tit: IBreadCrumbs = {
      path: path.startsWith("/")
        ? path
        : `${parent ? `${parent}/` : parent}${path}`,
      title
    };
    t.push(tit);
    if (children) t.push(...getChildren(children, tit.path));
  });
  return t;
};

export const getTitle: (route: Route) => string = route => {
  let title = getTitleByPath(route.path);
  if (title) return title;
  let length = route.matched.length;
  while (!title && length--) {
    title = getTitleByPath(route.matched[length].path);
  }
  return title;
};
export const getTitleByPath = (path: string) => {
  let title = "";
  titles.forEach(t => {
    if (t.path === path) title = t.title;
  });
  return title;
};
export const dateFormat = (fmt: string, x: Date | string) => {
  const date = typeof x === "string" ? new Date(x) : x;
  let ret;
  let opt: IAny = {
    "Y+": date.getFullYear().toString(), // 年
    "M+": (date.getMonth() + 1).toString(), // 月
    "d+": date.getDate().toString(), // 日
    "h+": date.getHours().toString(), // 时
    "m+": date.getMinutes().toString(), // 分
    "s+": date.getSeconds().toString() // 秒
    // 有其他格式化字符需求可以继续添加，必须转化成字符串
  };
  for (let k in opt) {
    ret = new RegExp("(" + k + ")").exec(fmt);
    if (ret) {
      fmt = fmt.replace(
        ret[1],
        ret[1].length == 1 ? opt[k] : opt[k].padStart(ret[1].length, "0")
      );
    }
  }
  return fmt;
};
